from mw2fcitx.pipeline import MWFPipeline
from mw2fcitx.tweaks.moegirl import tweak_opencc_t2s


def test_opencc_t2s():
    pipeline = MWFPipeline()
    pipeline.load_titles(["禮節"])
    pipeline.convert_to_words([tweak_opencc_t2s])
    print(pipeline.titles)
    pipeline.export_words(converter="pypinyin")
    assert pipeline.exports == "礼节\tli'jie\t0\n"


def test_dedup():
    pipeline = MWFPipeline()
    pipeline.load_titles(["禮節", "礼节"])
    pipeline.convert_to_words([tweak_opencc_t2s])
    pipeline.export_words(converter="pypinyin")
    assert pipeline.exports == "礼节\tli'jie\t0\n"



# pylint: disable=duplicate-code

exports = {
    "source": {
        "api_path": "https://zh.wikipedia.org/w/api.php",
        "kwargs": {
            "title_limit": 10,
            "api_params": {
                "action": "query",
                "list": "categorymembers",
                "cmtitle": "Category:天津市历史风貌建筑",
                "cmlimit": 5
            },
            "output": "test_list_categorymembers.titles.txt"
        }
    },
    "tweaks": [],
    "converter": {
        "use": "opencc",
        "kwargs": {}
    },
    "generator": []
}
